@@ -3,6 +3,7 @@
 # Uses opencv video capture to capture system's camera
 # Adapts to operating system and allows configuation of codec
 # Urs Utzinger
+# 
 # 2021 Initialize, Remove Frame acces (use only queue)
 # 2019 Initial release, based on Bitbuckets FRC 4183 code
 ###############################################################################
@@ -40,7 +41,7 @@ class cv2Capture(Thread):
         
         # populate desired settings from configuration file or function arguments
         ####################################################################
-        self.camera_num       = camera_num
+        self._camera_num       = camera_num
         if exposure is not None:
             self._exposure    = exposure  
         else: 
@@ -133,6 +134,7 @@ class cv2Capture(Thread):
                 else:
                     if not self.log.full(): self.log.put_nowait((logging.WARNING, "CV2:Capture Queue is full!"))
 
+
             # FPS calculation
             if (current_time - last_time) >= 5.0: # update frame rate every 5 secs
                 self.measured_fps = num_frames/5.0
@@ -151,13 +153,13 @@ class cv2Capture(Thread):
 
         # Open the camera with platform optimal settings
         if sys.platform.startswith('win'):
-            self.cam = cv2.VideoCapture(self.camera_num, apiPreference=cv2.CAP_MSMF)
+            self.cam = cv2.VideoCapture(self._camera_num, apiPreference=cv2.CAP_MSMF)
         elif sys.platform.startswith('darwin'):
-            self.cam = cv2.VideoCapture(self.camera_num, apiPreference=cv2.CAP_AVFOUNDATION)
+            self.cam = cv2.VideoCapture(self._camera_num, apiPreference=cv2.CAP_AVFOUNDATION)
         elif sys.platform.startswith('linux'):
-            self.cam = cv2.VideoCapture(self.camera_num, apiPreference=cv2.CAP_V4L2)
+            self.cam = cv2.VideoCapture(self._camera_num, apiPreference=cv2.CAP_V4L2)
         else:
-            self.cam = cv2.VideoCapture(self.camera_num, apiPreference=cv2.CAP_ANY)
+            self.cam = cv2.VideoCapture(self._camera_num, apiPreference=cv2.CAP_ANY)
 
         self.cam_open = self.cam.isOpened()
 
